# Generated by Django 3.0.3 on 2020-05-05 21:20

from django.db import migrations, models
import django.db.models.deletion
import django_user_email_extension.validators


class Migration(migrations.Migration):

    dependencies = [
        ('django_user_email_extension', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='address',
            field=models.ManyToManyField(to='django_user_email_extension.Address', verbose_name='Address'),
        ),
        migrations.AlterField(
            model_name='user',
            name='birth_date',
            field=models.DateField(blank=True, null=True, validators=[django_user_email_extension.validators.validate_users_min_age], verbose_name='Birth Date'),
        ),
        migrations.AlterField(
            model_name='user',
            name='default_phone_number',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='django_user_email_extension.PhoneNumber', verbose_name='Default Contact Number'),
        ),
        migrations.AlterField(
            model_name='user',
            name='gender',
            field=models.CharField(choices=[('m', 'Male'), ('f', 'Female'), ('x', 'Not specified')], default='x', max_length=1, verbose_name='Gender'),
        ),
    ]
